@@ -354,7 +354,7 @@ void repomanager::replaceRepos(const QString &url)
     if (ver_num == "8") {
         ver_name = "jessie";
     } else if (ver_num == "9") {
-        ver_name = "sid";
+        ver_name = "testing";
     }
 
     // for antiX repos
@@ -515,6 +515,9 @@ QIcon repomanager::getFlag(QString country)
     if (country == "The Netherlands" ) { country = "Netherlands"; }
     // fix flag of the United States of America  : QLocale::UnitedStates
     if (country == "USA" )             { country = "UnitedStates"; }
+    if (country == "Anycast" || country == "Any" || country == "World") {
+        return QIcon("/usr/share/fskbsetting/flags/any.png");
+    }
     //QMetaEnum metaEnum = QMetaEnum::fromType<QLocale::Country>(); -- not in older Qt versions
     int index = metaEnum.keyToValue(country.remove(" ").toUtf8());
     QList<QLocale> locales = QLocale::matchingLocales(QLocale::AnyLanguage, QLocale::AnyScript, QLocale::Country(index));
